@@ -11,7 +11,7 @@ use Data::Dumper ();
 
 $ENV{ANSI_COLORS_DISABLED} = 1 if $^O eq 'MSWin32';
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 my $org_execute               = \&DBI::st::execute;
 my $org_bind_param            = \&DBI::st::bind_param;
@@ -39,6 +39,8 @@ my $selectall_arrayref;
 my $selectrow_arrayref;
 my $selectrow_array;
 
+my $is_enabled = 0;
+
 sub import {
     my ($class) = @_;
 
@@ -60,6 +62,8 @@ sub import {
         *DBI::db::selectrow_arrayref = $selectrow_arrayref;
         *DBI::db::selectrow_array    = $selectrow_array;
     }
+
+    $is_enabled = 1;
 }
 
 sub unimport {
@@ -72,6 +76,8 @@ sub unimport {
         *DBI::db::selectrow_arrayref = $org_db_selectrow_arrayref;
         *DBI::db::selectrow_array    = $org_db_selectrow_array;
     }
+
+    $is_enabled = 0;
 }
 
 *enable  = *begin = \&import;
@@ -82,6 +88,8 @@ sub guard {
     return DBIx::QueryLog::Guard->new();
 }
 
+sub is_enabled { $is_enabled }
+
 my $container = {};
 for my $accessor (qw{
     logger threshold probability skip_bind
@@ -536,7 +544,7 @@ And, you can also specify C<< DBIX_QUERYLOG_COMPACT >> environment variable.
 
 B<< EXPERIMENTAL >>
 
-Logged Explain. (only supports mysql, PostgreSQL is incompletly supported)
+Logged Explain. (only supports mysql, PostgreSQL is incompletely supported)
 
 This feature requires C<< Text::ASCIITable >> installed.
 
@@ -582,6 +590,16 @@ This code same as are:
   # ... do something
   DBIx::QueryLog->disable;
 
+=item is_enabled
+
+Return true or false
+
+  use DBIx::QueryLog ();
+
+  say DBIx::QueryLog->is_enabled;
+
+  DBIx::QueryLog->disable;
+
 SEE ALSO L<< Localization >> section.
 
 =back
